function [b, a] = besselFilterDirectForm(N, fc, fs, mode, G);

% This function computes direct-form coefficients for a digital Bessel 
% filter of order N with cutoff frequency fc at samplerate fs (both given 
% in Hz). 
%
% usage: 
%  [b, a] = besselFilterDirectForm(N, fc, fs, mode, G);
%
% input-variables:
%  -N: order of the filter
%  -fc: cutoff frequency in Hz (in case of bandpass or bandstop mode, this
%       should be a two-element vector)
%  -fs: samplerate in Hz
%  -mode: a string specifying the filter mode ('LP', 'HP', 'BP', 'BR',
%         'LS', 'HS', 'PK')
%  -G: gain for peak- and shelving filters (as raw amplitude factor)
%
% output-variables:
%  -b: feedforward coefficients
%  -a: feedback coefficients

%--------------------------------------------------------------------------

[z, p, k] = besselFilterDigitalZerosPolesAndGain(N, fc, fs, mode, G);
b = real(poly(z)) * k;
a = real(poly(p));
